---
title: Welcome to mkdocs-shadcn
summary: Beautifully designed mkdocs theme
sidebar_title: Home
order: 0
external_links:
  "shadcn/ui": https://ui.shadcn.com/docs
---


First and foremost, this is an unofficial port of [shadcn/ui](https://ui.shadcn.com/) to [MkDocs](https://www.mkdocs.org), and is not affiliated with [@shadcn](https://twitter.com/shadcn).

The main goal of this project is to port the shadcn style to mkdocs while avoiding to turn it into a whole framework of the death.

So first it should support [built-in extensions](https://python-markdown.github.io/extensions/) and some [`pymdownx`](https://facelessuser.github.io/pymdown-extensions/) ones.


!!! info "Migrating from mkdocs-material? "
    In the general case, I would advise **not migrating** from [mkdocs-material](https://squidfunk.github.io/mkdocs-material/) since this theme is well established, very mature, with a lot of features we love.

    You can easily migrate to this theme if your documentaion does not rely on too many extensions/plugins. Of course, this is also a good choice for your next brand new project!
  
